==> gtg-0.2.tgz: lib/python2.5/site-packages/GTG/info.py <==
# -*- coding: utf-8 -*-
#various information about GTG. Should be updated for every release.

URL             = "http://gtg.fritalk.com"
EMAIL           = "gtg@lists.launchpad.net"
VERSION         = '0.2'

SHORT_DESCRIPTION = 'GTG is a personal organizer for the GNOME desktop environment.'

# CREDITS
AUTHORS     = ["Main developers:", \
               "\tLionel Dricot <ploum@ploum.net>", \
               "\tBertrand Rousseau <bertrand.rousseau@gmail.com>", \
               "\tPaulo Cabido <paulo.cabido@gmail.com>", \
               "\tLuca Invernizzi <invernizzi.l@gmail.com>", \
               "\tKevin Mehall <km@kevinmehall.net>", \
               "\tLuca Falavigna <dktrkranz@debian.org>", \
               "Contributors:", \
               "\tGérôme Fournier <>", \
               "\tAntons Rebguns <arebgun@gmail.com>", \
               "\tCarl Chenet <chaica@ohmytux.com>", \
               "\tJérôme Guelfucci <jerome.guelfucci@gmail.com>",      \
               "\tKalle Persson <kalle@kallepersson.se>", \
               "\tJonathan Barnoud <jonathan@barnoud.net>", \
               "\tMichael Vogt <michael.vogt@ubuntu.com>", \
               "\tBen Dowling <ben.m.dowling@gmail.com>", \
               "\tBrian Kennedy <ekspiulo@gmail.com>", \
               "\tZach Shepherd <eightball1989@gmail.com>", \
               "\tJean-François Fortin Tam <nekohayo@gmail.com>", \
               "\tJonathan Lange <jml@mumak.net>", \
]
ARTISTS     = ["Kalle Persson <kalle@kallepersson.se>", \
                "Bertrand Rousseau <bertrand.rousseau@gmail.com>"]
ARTISTS.sort()
TRANSLATORS = \
"""Afrikaans: Walter Leibbrandt
Belarusian: Egor Kuryanovich, Iryna Nikanchuk
Catalan: Siegfried Gevatter
Czech: Hýroumen, Ladislav Prskavec
Danish: Peter Skov
Dutch: puccha
Finnish: Mika Tapojärvi
French: Lionel Dricot, Rafik Ouerchefani, Bertrand Rousseau, Pititjo
German: Philip Stewart, Thomas Pitlik
Italian: Luca Falavigna, Luca Invernizzi
Malay: melayubuntu
Polish: Tomasz Maciejewski
Portuguese: Paulo Cabido 
Russian: Alexey Kostyuk, Alexey Nedilko, a220, mrk, wiz
Simplified Chinese: Harold.luo
Spanish: David Prieto, DiegoJ, Pititjo
Swedish: Christian Widell, Daniel Holm, Kalle Persson, Petri Rosenström
Turkish: Murat Güneş"""

==> gtg-0.2.3.tgz: lib/python2.5/site-packages/GTG/info.py <==
# -*- coding: utf-8 -*-
#various information about GTG. Should be updated for every release.

URL             = "http://gtg.fritalk.com"
EMAIL           = "gtg-contributors@lists.launchpad.net"
VERSION         = '0.2.3'

SHORT_DESCRIPTION = 'GTG is a personal organizer for the GNOME desktop environment.'

# CREDITS
AUTHORS     = ["Main developers:", \
               "\tLionel Dricot <ploum@ploum.net>", \
               "\tBertrand Rousseau <bertrand.rousseau@gmail.com>", \
               "\tPaulo Cabido <paulo.cabido@gmail.com>", \
               "\tLuca Invernizzi <invernizzi.l@gmail.com>", \
               "\tKevin Mehall <km@kevinmehall.net>", \
               "\tLuca Falavigna <dktrkranz@debian.org>", \
               "Contributors:", \
               "\tGérôme Fournier <>", \
               "\tAntons Rebguns <arebgun@gmail.com>", \
               "\tCarl Chenet <chaica@ohmytux.com>", \
               "\tJérôme Guelfucci <jerome.guelfucci@gmail.com>",      \
               "\tKalle Persson <kalle@kallepersson.se>", \
               "\tJonathan Barnoud <jonathan@barnoud.net>", \
               "\tMichael Vogt <michael.vogt@ubuntu.com>", \
               "\tBen Dowling <ben.m.dowling@gmail.com>", \
               "\tBrian Kennedy <ekspiulo@gmail.com>", \
               "\tZach Shepherd <eightball1989@gmail.com>", \
               "\tJean-François Fortin Tam <nekohayo@gmail.com>", \
               "\tJonathan Lange <jml@mumak.net>", \
               "\tMatthew Rasmus <tareth.ml@gmail.com>", \
               "\tBryce Harrington <bryce@bryceharrington.org>", \
               "\tChris Johnston <chrisjohnston@ubuntu.com>", \
]
ARTISTS     = ["Kalle Persson <kalle@kallepersson.se>", \
                "Bertrand Rousseau <bertrand.rousseau@gmail.com>"]
ARTISTS.sort()
TRANSLATORS = \
"""Afrikaans: Walter Leibbrandt
Belarusian: Egor Kuryanovich, Iryna Nikanchuk
Catalan: Siegfried Gevatter
Czech: Hýroumen, Ladislav Prskavec
Danish: Peter Skov
Dutch: puccha
Finnish: Mika Tapojärvi
French: Lionel Dricot, Rafik Ouerchefani, Bertrand Rousseau, Pititjo
German: Philip Stewart, Thomas Pitlik
Italian: Luca Falavigna, Luca Invernizzi
Malay: melayubuntu
Polish: Tomasz Maciejewski
Portuguese: Paulo Cabido 
Russian: Alexey Kostyuk, Alexey Nedilko, a220, mrk, wiz
Simplified Chinese: Harold.luo
Spanish: David Prieto, DiegoJ, Pititjo
Swedish: Christian Widell, Daniel Holm, Kalle Persson, Petri Rosenström
Turkish: Murat Güneş"""
